```python
def hello(name):
  print(f"Hello, {name}!")

hello("LitREPL")
```

```
Hello, LitREPL!
```

```python
hello("World")
```

```
Hello, World!
```

* List
* <!--litrepl-->
  BLABLA
  <!--litrepl-->
